function compartmentGeometry = RWScreateCompartmentDifference(T2,intraCompartmentDiffusivity,membranePermeability,...
    baseCompartment,varargin)
% function compartmentGeometry  =
% RWScreateCompartmentDifference(intraCompartmentDiffusivity,transmissionProbability,...
%   baseCompartment,varargin)
%
%   Create a restriction environment based on the set difference between a 
%   "base" compartment and the union of existing environments. 
%   Compartment properties from the compoenent compartments are ignored. 
%
%   Inputs:
%       T2 - T2 of the compartment in us
%       intraCompartmentDiffusivity - intra-compartment diffusivity um2/us
%       membranePermeability - um/us
%       baseCompartment - geometric inclusion criteria
%       varargin - list of compartment objects which to exclude
%
%   Outputs:
%       compartmentGometry - an object to describe the compartment
%       geometry.
% ***********************************************
% RandomWalkSimulator v2.0
% Major Revision by:
% 	Bennett Landman, landman@jhu.edu
% 	Jonathan Farrell, jfarrell@jhu.edu
%   (C) Copyright 2008, Bennett Landman and Jonathan Farrell
%   Released under Lessor GNU Public License v1.0
% 	Not for clinical use.
% 	No warranty expressed or implied.
%   Use at your own risk.
% Download at: http://www.nitrc.org/projects/randomwalks/
% ***********************************************
% 10/15/08 bl

import bl.diffusion.*;

% bug fix by jfarrell
compartmentGeometry.javaObject = SimCompartmentDifference(membranePermeability,intraCompartmentDiffusivity,T2,...
    baseCompartment.javaObject);
compartmentGeometry.name= 'Difference';
compartmentGeometry.diffusivity=intraCompartmentDiffusivity;
compartmentGeometry.permeability=membranePermeability;
for j=1:length(varargin)    
    compartmentGeometry.javaObject.removeCompartment(varargin{j}.javaObject);
    MX(j,:)=max(varargin{j}.shape.vertices);
    MN(j,:)=min(varargin{j}.shape.vertices); 
end
MX(end+1,:)=max(baseCompartment.shape.vertices);
MN(end+1,:)=min(baseCompartment.shape.vertices); 
mx = max(MX,[],1)+.1*max(MX(:)-MN(:));
mn = min(MN,[],1)-.1*max(MX(:)-MN(:));

    [X,Y,Z]=ndgrid(linspace(mn(1),mx(1),51),...
        linspace(mn(2),mx(2),51),...
        linspace(mn(3),mx(3),51)...
        );
    mask = X;
    for i=1:size(X,1)
        for j=1:size(X,2)
            for k=1:size(X,3)
                mask(i,j,k)=compartmentGeometry.javaObject.contains(PT(X(i,j,k),Y(i,j,k),Z(i,j,k)));
            end
        end
    end
    
 V = smooth3(...     
     mask);
     
 compartmentGeometry.shape=isosurface(X,Y,Z,V  ,0.5);
%   figure(99);clf;patch(compartmentGeometry.shape,'facealpha',.1,'facecolor','r','edgecolor','none');light;lighting phong

