function compartmentGeometry = RWScreateCompartmentIntersection(T2,intraCompartmentDiffusivity,membranePermeability,varargin)
% function compartmentGeometry  =
% RWScreateCompartmentIntersection(intraCompartmentDiffusivity,membranePermeability,varargin)
%
%   Create a restriction environment based on the intersection of several existing environments. 
%   Compartment properties from the compoenent compartments are ignored. 
%
%   Inputs:
%       T2 - T2 of the compartment in us
%       intraCompartmentDiffusivity - intra-compartment diffusivity um2/us
%       membranePermeability - um/us
%       varargin - list of compartment objects from which to create a union
%       shape.
%
%   Outputs:
%       compartmentGometry - an object to describe the compartment
%       geometry.
% ***********************************************
% RandomWalkSimulator v2.0
% Major Revision by:
% 	Bennett Landman, landman@jhu.edu
% 	Jonathan Farrell, jfarrell@jhu.edu
%   (C) Copyright 2008, Bennett Landman and Jonathan Farrell
%   Released under Lessor GNU Public License v1.0
% 	Not for clinical use.
% 	No warranty expressed or implied.
%   Use at your own risk.
% Download at: http://www.nitrc.org/projects/randomwalks/
% ***********************************************
% 9/15/08 bl

import bl.diffusion.*;


compartmentGeometry.javaObject = SimCompartmentIntersection(membranePermeability,intraCompartmentDiffusivity,T2);
compartmentGeometry.name= 'Intersection';
compartmentGeometry.diffusivity=intraCompartmentDiffusivity;
compartmentGeometry.permeability=membranePermeability;
for j=1:length(varargin)    
    compartmentGeometry.javaObject.addCompartment(varargin{j}.javaObject);
    MX(j,:)=max(varargin{j}.shape.vertices);
    MN(j,:)=min(varargin{j}.shape.vertices);
%     figure(j)
%     patch(varargin{j}.shape,'facecolor','r')
%     axis tight;
    
end
mx = min(MX,[],1)+.1*max(MX(:)-MN(:));
mn = max(MN,[],1)-.1*max(MX(:)-MN(:));

    [X,Y,Z]=ndgrid(linspace(mn(1),mx(1),51),...
        linspace(mn(2),mx(3),51),...
        linspace(mn(2),mx(3),51)...
        );
    mask = X;
    for i=1:size(X,1)
        for j=1:size(X,2)
            for k=1:size(X,3)
                mask(i,j,k)=compartmentGeometry.javaObject.contains(PT(X(i,j,k),Y(i,j,k),Z(i,j,k)));
            end
        end
    end
    
 V = smooth3(...     
     mask);
     
 compartmentGeometry.shape=isosurface(X,Y,Z,V  ,0.5);
%  figure(99);clf;patch(compartmentGeometry.shape,'facecolor','r','edgecolor','none');light;lighting phong

